==> kubernetes-model-1.0.48-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/IngressSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.List;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class IngressSpecBuilder extends IngressSpecFluentImpl<IngressSpecBuilder> implements VisitableBuilder<IngressSpec,IngressSpecBuilder>{

     IngressSpecFluent<?> fluent;
public IngressSpecBuilder(){
    this(new IngressSpec());
}
public IngressSpecBuilder( IngressSpecFluent<?> fluent ){
    this(fluent, new IngressSpec());
}
public IngressSpecBuilder( IngressSpecFluent<?> fluent , IngressSpec instance ){
    this.fluent = fluent; fluent.withBackend(instance.getBackend()); fluent.withRules(instance.getRules()); fluent.withTls(instance.getTls()); 
}
public IngressSpecBuilder( IngressSpec instance ){
    this.fluent = this; this.withBackend(instance.getBackend()); this.withRules(instance.getRules()); this.withTls(instance.getTls()); 
}

public EditableIngressSpec build(){
    EditableIngressSpec buildable = new EditableIngressSpec(fluent.getBackend(),fluent.getRules(),fluent.getTls());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
IngressSpecBuilder that = (IngressSpecBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/IngressSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.List;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class IngressSpecBuilder extends IngressSpecFluentImpl<IngressSpecBuilder> implements VisitableBuilder<IngressSpec,IngressSpecBuilder>{

     IngressSpecFluent<?> fluent;
public IngressSpecBuilder(){
    this(new IngressSpec());
}
public IngressSpecBuilder( IngressSpecFluent<?> fluent ){
    this(fluent, new IngressSpec());
}
public IngressSpecBuilder( IngressSpecFluent<?> fluent , IngressSpec instance ){
    this.fluent = fluent; fluent.withBackend(instance.getBackend()); fluent.withRules(instance.getRules()); fluent.withTls(instance.getTls()); 
}
public IngressSpecBuilder( IngressSpec instance ){
    this.fluent = this; this.withBackend(instance.getBackend()); this.withRules(instance.getRules()); this.withTls(instance.getTls()); 
}

public IngressSpec build(){
    IngressSpec buildable = new IngressSpec(fluent.getBackend(),fluent.getRules(),fluent.getTls());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
IngressSpecBuilder that = (IngressSpecBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
